from django.db.models import Model

from typing_extensions import Type

from dandy.llm import Prompt


def objective_prompt(
    model_class: Type[Model],
    model_description: str,
    sector_description: str,
) -> Prompt:
    model_name = model_class._meta.verbose_name_plural.title()

    return (
        Prompt()
        .text(f'You are generating "{model_name}" that are described as "{model_description}".')
        .text(f'These {model_name} represent entities in our "{sector_description}" system.')
    )



from dandy.llm import BaseLlmBot

from django_spire.ai.prompt.system import prompts
from django_spire.ai.prompt.system import intel


class SystemPromptBot(BaseLlmBot):
    instructions_prompt = prompts.system_prompt_instruction_bot_prompt()
    intel_class = intel.SystemPromptIntel


    @classmethod
    def process(
            cls,
            user_story: str

    ) -> intel.SystemPromptIntel:

        return cls.process_prompt_to_intel(
            prompt=prompts.system_user_input_prompt(user_story)
        )



from __future__ import annotations

from dandy.intel import BaseIntel


class DandyPromptPythonFileIntel(BaseIntel):
    source_code: str
    file_name: str


class TextToMarkdownIntel(BaseIntel):
    markdown_content: str
    file_name: str



from pathlib import Path

from dandy.llm import BaseLlmBot
from django.conf import settings

from django_spire.ai.prompt import prompts
from django_spire.ai.prompt import intel

_PROMPT_OUTPUT_PATH = Path(settings.BASE_DIR, '.prompt_generator_output')
_MARKDOWN_OUTPUT_PATH = Path(settings.BASE_DIR, '.markdown')


class DandyPythonPromptBot(BaseLlmBot):
    instructions_prompt = prompts.dandy_prompt_python_file_instruction_bot_prompt()
    intel_class = intel.DandyPromptPythonFileIntel

    @classmethod
    def process(
            cls,
            prompt: str,

    ) -> intel.DandyPromptPythonFileIntel:
        """
            Takes in an enhanced prompt and turn it into a python file that uses the dandy library.
        """
        prompt_file = cls.process_prompt_to_intel(
            prompt=prompts.dandy_prompt_python_file_input_prompt(prompt)
        )

        Path(_PROMPT_OUTPUT_PATH).mkdir(parents=True, exist_ok=True)

        with open(Path(_PROMPT_OUTPUT_PATH, prompt_file.file_name), 'w') as f:
            f.write(prompt_file.source_code)

        print(f'Done ... saved to "{Path(_PROMPT_OUTPUT_PATH, prompt_file.file_name)}"')

        return prompt_file


class TextToMarkdownPromptBot(BaseLlmBot):
    instructions_prompt = prompts.text_to_markdown_instruction_bot_prompt()
    intel_class = intel.TextToMarkdownIntel

    @classmethod
    def process(
            cls,
            text: str,

    ) -> intel.TextToMarkdownIntel:
        """
            Takes in user text and converts it to properly formatted Markdown.
        """
        markdown_file = cls.process_prompt_to_intel(
            prompt=prompts.text_to_markdown_input_prompt(text)
        )

        Path(_MARKDOWN_OUTPUT_PATH).mkdir(parents=True, exist_ok=True)

        with open(Path(_MARKDOWN_OUTPUT_PATH, markdown_file.file_name), 'w') as f:
            f.write(markdown_file.markdown_content)

        print(f'Done ... saved to "{Path(_MARKDOWN_OUTPUT_PATH, markdown_file.file_name)}"')

        return markdown_file



from django.urls import path

from module.views import page_views

app_name = 'page'
urlpatterns = [
    path('<int:pk>/detail/', page_views.detail_view, name='detail'),
    path('list/', page_views.list_view, name='list'),
]


from __future__ import annotations

from typing_extensions import TYPE_CHECKING

from django.contrib.auth.decorators import permission_required
from django.template.response import TemplateResponse

from django_spire.contrib import Breadcrumbs
from django_spire.contrib.generic_views import portal_views


if TYPE_CHECKING:
    from django.core.handlers.wsgi import WSGIRequest


def dashboard_view(request: WSGIRequest) -> TemplateResponse:
    crumbs = Breadcrumbs()
    crumbs.add_breadcrumb('Dashboard')

    return portal_views.template_view(
        request,
        page_title='Theme',
        page_description='Dashboard',
        breadcrumbs=crumbs,
        template='django_spire/theme/page/dashboard_page.html'
    )


def colors_view(request: WSGIRequest) -> TemplateResponse:
    crumbs = Breadcrumbs()
    crumbs.add_breadcrumb('Dashboard', 'theme:page:dashboard')
    crumbs.add_breadcrumb('Colors')

    return portal_views.template_view(
        request,
        page_title='Theme',
        page_description='Colors',
        breadcrumbs=crumbs,
        template='django_spire/theme/page/colors_page.html'
    )


def typography_view(request: WSGIRequest) -> TemplateResponse:
    crumbs = Breadcrumbs()
    crumbs.add_breadcrumb('Dashboard', 'theme:page:dashboard')
    crumbs.add_breadcrumb('Typography')

    return portal_views.template_view(
        request,
        page_title='Theme',
        page_description='Typography',
        breadcrumbs=crumbs,
        template='django_spire/theme/page/typography_page.html'
    )


def buttons_view(request: WSGIRequest) -> TemplateResponse:
    crumbs = Breadcrumbs()
    crumbs.add_breadcrumb('Dashboard', 'theme:page:dashboard')
    crumbs.add_breadcrumb('Buttons')

    return portal_views.template_view(
        request,
        page_title='Theme',
        page_description='Buttons',
        breadcrumbs=crumbs,
        template='django_spire/theme/page/buttons_page.html'
    )


def badges_view(request: WSGIRequest) -> TemplateResponse:
    crumbs = Breadcrumbs()
    crumbs.add_breadcrumb('Dashboard', 'theme:page:dashboard')
    crumbs.add_breadcrumb('Badges')

    return portal_views.template_view(
        request,
        page_title='Theme',
        page_description='Badges',
        breadcrumbs=crumbs,
        template='django_spire/theme/page/badges_page.html'
    )


def borders_view(request: WSGIRequest) -> TemplateResponse:
    crumbs = Breadcrumbs()
    crumbs.add_breadcrumb('Dashboard', 'theme:page:dashboard')
    crumbs.add_breadcrumb('Borders')

    return portal_views.template_view(
        request,
        page_title='Theme',
        page_description='Borders',
        breadcrumbs=crumbs,
        template='django_spire/theme/page/borders_page.html'
    )
